==> openshift-model-machine-5.10.2-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineHealthCheckStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class MachineHealthCheckStatusFluentImpl<A extends io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent<A>{
  public MachineHealthCheckStatusFluentImpl() {
  }
  public MachineHealthCheckStatusFluentImpl(io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatus instance) {
    this.withConditions(instance.getConditions()); 
    this.withCurrentHealthy(instance.getCurrentHealthy()); 
    this.withExpectedMachines(instance.getExpectedMachines()); 
    this.withRemediationsAllowed(instance.getRemediationsAllowed()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder> conditions =  new java.util.ArrayList<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder>();
  private java.lang.Integer currentHealthy;
  private java.lang.Integer expectedMachines;
  private java.lang.Integer remediationsAllowed;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.machine.v1beta1.Condition item) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder>();}
    io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder builder = new io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder(item);_visitables.get("conditions").add(index >= 0 ? index : _visitables.get("conditions").size(), builder);this.conditions.add(index >= 0 ? index : conditions.size(), builder); return (A)this;
  }
  public A setToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.machine.v1beta1.Condition item) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder>();}
    io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder builder = new io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder(item);
    if (index < 0 || index >= _visitables.get("conditions").size()) { _visitables.get("conditions").add(builder); } else { _visitables.get("conditions").set(index, builder);}
    if (index < 0 || index >= conditions.size()) { conditions.add(builder); } else { conditions.set(index, builder);}
     return (A)this;
  }
  public A addToConditions(io.fabric8.openshift.api.model.machine.v1beta1.Condition... items) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder>();}
    for (io.fabric8.openshift.api.model.machine.v1beta1.Condition item : items) {io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder builder = new io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A addAllToConditions(java.util.Collection<io.fabric8.openshift.api.model.machine.v1beta1.Condition> items) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder>();}
    for (io.fabric8.openshift.api.model.machine.v1beta1.Condition item : items) {io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder builder = new io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A removeFromConditions(io.fabric8.openshift.api.model.machine.v1beta1.Condition... items) {
    for (io.fabric8.openshift.api.model.machine.v1beta1.Condition item : items) {io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder builder = new io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
  }
  public A removeAllFromConditions(java.util.Collection<io.fabric8.openshift.api.model.machine.v1beta1.Condition> items) {
    for (io.fabric8.openshift.api.model.machine.v1beta1.Condition item : items) {io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder builder = new io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder> predicate) {
    if (conditions == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder> each = conditions.iterator();
    final List visitables = _visitables.get("conditions");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.machine.v1beta1.Condition> getConditions() {
    return build(conditions);
  }
  public java.util.List<io.fabric8.openshift.api.model.machine.v1beta1.Condition> buildConditions() {
    return build(conditions);
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.Condition buildCondition(java.lang.Integer index) {
    return this.conditions.get(index).build();
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.Condition buildFirstCondition() {
    return this.conditions.get(0).build();
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.Condition buildLastCondition() {
    return this.conditions.get(conditions.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.Condition buildMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder> predicate) {
    for (io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder item: conditions) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder> predicate) {
    for (io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder item: conditions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withConditions(java.util.List<io.fabric8.openshift.api.model.machine.v1beta1.Condition> conditions) {
    if (this.conditions != null) { _visitables.get("conditions").removeAll(this.conditions);}
    if (conditions != null) {this.conditions = new java.util.ArrayList<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder>(); for (io.fabric8.openshift.api.model.machine.v1beta1.Condition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
  }
  public A withConditions(io.fabric8.openshift.api.model.machine.v1beta1.Condition... conditions) {
    if (this.conditions != null) {this.conditions.clear();}
    if (conditions != null) {for (io.fabric8.openshift.api.model.machine.v1beta1.Condition item :conditions){ this.addToConditions(item);}} return (A) this;
  }
  public java.lang.Boolean hasConditions() {
    return conditions != null && !conditions.isEmpty();
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent.ConditionsNested<A> addNewCondition() {
    return new io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluentImpl.ConditionsNestedImpl();
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.openshift.api.model.machine.v1beta1.Condition item) {
    return new io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluentImpl.ConditionsNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.openshift.api.model.machine.v1beta1.Condition item) {
    return new io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluentImpl.ConditionsNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent.ConditionsNested<A> editCondition(java.lang.Integer index) {
    if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent.ConditionsNested<A> editFirstCondition() {
    if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
    return setNewConditionLike(0, buildCondition(0));
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent.ConditionsNested<A> editLastCondition() {
    int index = conditions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<conditions.size();i++) { 
    if (predicate.test(conditions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public java.lang.Integer getCurrentHealthy() {
    return this.currentHealthy;
  }
  public A withCurrentHealthy(java.lang.Integer currentHealthy) {
    this.currentHealthy=currentHealthy; return (A) this;
  }
  public java.lang.Boolean hasCurrentHealthy() {
    return this.currentHealthy != null;
  }
  public java.lang.Integer getExpectedMachines() {
    return this.expectedMachines;
  }
  public A withExpectedMachines(java.lang.Integer expectedMachines) {
    this.expectedMachines=expectedMachines; return (A) this;
  }
  public java.lang.Boolean hasExpectedMachines() {
    return this.expectedMachines != null;
  }
  public java.lang.Integer getRemediationsAllowed() {
    return this.remediationsAllowed;
  }
  public A withRemediationsAllowed(java.lang.Integer remediationsAllowed) {
    this.remediationsAllowed=remediationsAllowed; return (A) this;
  }
  public java.lang.Boolean hasRemediationsAllowed() {
    return this.remediationsAllowed != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    MachineHealthCheckStatusFluentImpl that = (MachineHealthCheckStatusFluentImpl) o;
    if (conditions != null ? !conditions.equals(that.conditions) :that.conditions != null) return false;
    if (currentHealthy != null ? !currentHealthy.equals(that.currentHealthy) :that.currentHealthy != null) return false;
    if (expectedMachines != null ? !expectedMachines.equals(that.expectedMachines) :that.expectedMachines != null) return false;
    if (remediationsAllowed != null ? !remediationsAllowed.equals(that.remediationsAllowed) :that.remediationsAllowed != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(conditions,  currentHealthy,  expectedMachines,  remediationsAllowed,  additionalProperties,  super.hashCode());
  }
  public class ConditionsNestedImpl<N> extends io.fabric8.openshift.api.model.machine.v1beta1.ConditionFluentImpl<io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent.ConditionsNested<N>> implements io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent.ConditionsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ConditionsNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.machine.v1beta1.Condition item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder(this, item);
    }
    ConditionsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder(this);
    }
    io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) MachineHealthCheckStatusFluentImpl.this.setToConditions(index,builder.build());
    }
    public N endCondition() {
      return and();
    }
    
  }
  
}

==> openshift-model-machine-5.12.1-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineHealthCheckStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class MachineHealthCheckStatusFluentImpl<A extends io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent<A>{
  public MachineHealthCheckStatusFluentImpl() {
  }
  public MachineHealthCheckStatusFluentImpl(io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatus instance) {
    this.withConditions(instance.getConditions()); 
    this.withCurrentHealthy(instance.getCurrentHealthy()); 
    this.withExpectedMachines(instance.getExpectedMachines()); 
    this.withRemediationsAllowed(instance.getRemediationsAllowed()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder> conditions =  new java.util.ArrayList<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder>();
  private java.lang.Integer currentHealthy;
  private java.lang.Integer expectedMachines;
  private java.lang.Integer remediationsAllowed;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.machine.v1beta1.Condition item) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder>();}
    io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder builder = new io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder(item);_visitables.get("conditions").add(index >= 0 ? index : _visitables.get("conditions").size(), builder);this.conditions.add(index >= 0 ? index : conditions.size(), builder); return (A)this;
  }
  public A setToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.machine.v1beta1.Condition item) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder>();}
    io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder builder = new io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder(item);
    if (index < 0 || index >= _visitables.get("conditions").size()) { _visitables.get("conditions").add(builder); } else { _visitables.get("conditions").set(index, builder);}
    if (index < 0 || index >= conditions.size()) { conditions.add(builder); } else { conditions.set(index, builder);}
     return (A)this;
  }
  public A addToConditions(io.fabric8.openshift.api.model.machine.v1beta1.Condition... items) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder>();}
    for (io.fabric8.openshift.api.model.machine.v1beta1.Condition item : items) {io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder builder = new io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A addAllToConditions(java.util.Collection<io.fabric8.openshift.api.model.machine.v1beta1.Condition> items) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder>();}
    for (io.fabric8.openshift.api.model.machine.v1beta1.Condition item : items) {io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder builder = new io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A removeFromConditions(io.fabric8.openshift.api.model.machine.v1beta1.Condition... items) {
    for (io.fabric8.openshift.api.model.machine.v1beta1.Condition item : items) {io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder builder = new io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
  }
  public A removeAllFromConditions(java.util.Collection<io.fabric8.openshift.api.model.machine.v1beta1.Condition> items) {
    for (io.fabric8.openshift.api.model.machine.v1beta1.Condition item : items) {io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder builder = new io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder> predicate) {
    if (conditions == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder> each = conditions.iterator();
    final List visitables = _visitables.get("conditions");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.machine.v1beta1.Condition> getConditions() {
    return build(conditions);
  }
  public java.util.List<io.fabric8.openshift.api.model.machine.v1beta1.Condition> buildConditions() {
    return build(conditions);
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.Condition buildCondition(java.lang.Integer index) {
    return this.conditions.get(index).build();
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.Condition buildFirstCondition() {
    return this.conditions.get(0).build();
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.Condition buildLastCondition() {
    return this.conditions.get(conditions.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.Condition buildMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder> predicate) {
    for (io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder item: conditions) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder> predicate) {
    for (io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder item: conditions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withConditions(java.util.List<io.fabric8.openshift.api.model.machine.v1beta1.Condition> conditions) {
    if (this.conditions != null) { _visitables.get("conditions").removeAll(this.conditions);}
    if (conditions != null) {this.conditions = new java.util.ArrayList(); for (io.fabric8.openshift.api.model.machine.v1beta1.Condition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
  }
  public A withConditions(io.fabric8.openshift.api.model.machine.v1beta1.Condition... conditions) {
    if (this.conditions != null) {this.conditions.clear();}
    if (conditions != null) {for (io.fabric8.openshift.api.model.machine.v1beta1.Condition item :conditions){ this.addToConditions(item);}} return (A) this;
  }
  public java.lang.Boolean hasConditions() {
    return conditions != null && !conditions.isEmpty();
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent.ConditionsNested<A> addNewCondition() {
    return new io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluentImpl.ConditionsNestedImpl();
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.openshift.api.model.machine.v1beta1.Condition item) {
    return new io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluentImpl.ConditionsNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.openshift.api.model.machine.v1beta1.Condition item) {
    return new io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluentImpl.ConditionsNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent.ConditionsNested<A> editCondition(java.lang.Integer index) {
    if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent.ConditionsNested<A> editFirstCondition() {
    if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
    return setNewConditionLike(0, buildCondition(0));
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent.ConditionsNested<A> editLastCondition() {
    int index = conditions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<conditions.size();i++) { 
    if (predicate.test(conditions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public java.lang.Integer getCurrentHealthy() {
    return this.currentHealthy;
  }
  public A withCurrentHealthy(java.lang.Integer currentHealthy) {
    this.currentHealthy=currentHealthy; return (A) this;
  }
  public java.lang.Boolean hasCurrentHealthy() {
    return this.currentHealthy != null;
  }
  public java.lang.Integer getExpectedMachines() {
    return this.expectedMachines;
  }
  public A withExpectedMachines(java.lang.Integer expectedMachines) {
    this.expectedMachines=expectedMachines; return (A) this;
  }
  public java.lang.Boolean hasExpectedMachines() {
    return this.expectedMachines != null;
  }
  public java.lang.Integer getRemediationsAllowed() {
    return this.remediationsAllowed;
  }
  public A withRemediationsAllowed(java.lang.Integer remediationsAllowed) {
    this.remediationsAllowed=remediationsAllowed; return (A) this;
  }
  public java.lang.Boolean hasRemediationsAllowed() {
    return this.remediationsAllowed != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    MachineHealthCheckStatusFluentImpl that = (MachineHealthCheckStatusFluentImpl) o;
    if (conditions != null ? !conditions.equals(that.conditions) :that.conditions != null) return false;
    if (currentHealthy != null ? !currentHealthy.equals(that.currentHealthy) :that.currentHealthy != null) return false;
    if (expectedMachines != null ? !expectedMachines.equals(that.expectedMachines) :that.expectedMachines != null) return false;
    if (remediationsAllowed != null ? !remediationsAllowed.equals(that.remediationsAllowed) :that.remediationsAllowed != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(conditions,  currentHealthy,  expectedMachines,  remediationsAllowed,  additionalProperties,  super.hashCode());
  }
  public class ConditionsNestedImpl<N> extends io.fabric8.openshift.api.model.machine.v1beta1.ConditionFluentImpl<io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent.ConditionsNested<N>> implements io.fabric8.openshift.api.model.machine.v1beta1.MachineHealthCheckStatusFluent.ConditionsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ConditionsNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.machine.v1beta1.Condition item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder(this, item);
    }
    ConditionsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder(this);
    }
    io.fabric8.openshift.api.model.machine.v1beta1.ConditionBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) MachineHealthCheckStatusFluentImpl.this.setToConditions(index,builder.build());
    }
    public N endCondition() {
      return and();
    }
    
  }
  
}
